==> ssp-center-api-0.1.13-dzn07-20170816.035805-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/AppStatisticsDataRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;


import org.apache.commons.lang3.builder.ToStringBuilder;

import java.util.List;

/**
 * ClassName: AppStatisticsDataRsp <br/>
 * date: 2016年12月21日 上午11:31:11 <br/>
 * .
 *
 * @author xiawei
 * @version
 * @since JDK 1.6
 */
public class AppStatisticsDataRsp extends BaseStatisticsDataRsp {

    /** The Constant serialVersionUID. @since JDK 1.6 */
    private static final long serialVersionUID = 4185789708260616603L;

    /** 媒体ID. */
    private Long              appId;

    /** 媒体名称. */
    private String            appName;

    /** 系统平台. */
    private String            platform;

    /**日期*/
    private String            curDate;

    /** 用户ID */
    private Long              mediaId;

    /** 用户账号 */
    private String            account;

    private  List<Long>      managerList;

    private List<String>     managerNameList;

    /**
     * Gets the app id.
     *
     * @return the app id
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * Sets the app id.
     *
     * @param appId the app id
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * Gets the app name.
     *
     * @return the app name
     */
    public String getAppName() {
        return appName;
    }

    /**
     * Sets the app name.
     *
     * @param appName the app name
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * Gets the platform.
     *
     * @return the platform
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * Sets the platform.
     *
     * @param platform the platform
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * Gets the curDate.
     *
     * @return the curDate
     */
    public String getCurDate() {
        return curDate;
    }

    /**
     * Sets the curDate.
     *
     * @param curDate the curDate
     */
    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }


    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public List<Long> getManagerList() {
        return managerList;
    }

    public void setManagerList(List<Long> managerList) {
        this.managerList = managerList;
    }

    public List<String> getManagerNameList() {
        return managerNameList;
    }

    public void setManagerNameList(List<String> managerNameList) {
        this.managerNameList = managerNameList;
    }

    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> ssp-center-api-0.1.20-dzn9-20170915.115823-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/AppStatisticsDataRsp.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;


import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * ClassName: AppStatisticsDataRsp <br/>
 * date: 2016年12月21日 上午11:31:11 <br/>
 * .
 *
 * @author xiawei
 * @version
 * @since JDK 1.6
 */
public class AppStatisticsDataRsp extends BaseStatisticsDataRsp {

    /** The Constant serialVersionUID. @since JDK 1.6 */
    private static final long serialVersionUID = 4185789708260616603L;

    /** 媒体ID. */
    private Long              appId;

    /** 媒体名称. */
    private String            appName;

    /** 系统平台. */
    private String            platform;

    /**日期*/
    private String            curDate;

    /** 用户ID */
    private Long              mediaId;

    /** 用户账号 */
    private String            account;
    
    /** 一级标签 */
    private String            tagName1;
    /** 二级标签 */
    private String            tagName2;

    /**
     * Gets the app id.
     *
     * @return the app id
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * Sets the app id.
     *
     * @param appId the app id
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * Gets the app name.
     *
     * @return the app name
     */
    public String getAppName() {
        return appName;
    }

    /**
     * Sets the app name.
     *
     * @param appName the app name
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * Gets the platform.
     *
     * @return the platform
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * Sets the platform.
     *
     * @param platform the platform
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * Gets the curDate.
     *
     * @return the curDate
     */
    public String getCurDate() {
        return curDate;
    }

    /**
     * Sets the curDate.
     *
     * @param curDate the curDate
     */
    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }


    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }





    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

	public String getTagName1() {
		return tagName1;
	}

	public void setTagName1(String tagName1) {
		this.tagName1 = tagName1;
	}

	public String getTagName2() {
		return tagName2;
	}

	public void setTagName2(String tagName2) {
		this.tagName2 = tagName2;
	}

}
